@@ -3,7 +3,7 @@ package Plack;
 use strict;
 use warnings;
 use 5.008_001;
-our $VERSION = '0.99_22';
+our $VERSION = '0.99_23';
 $VERSION = eval $VERSION;
 
 1;
@@ -164,7 +164,7 @@ Tokuhiro Matsuno (tokuhirom)
 
 Kazuhiro Osawa (Yappo)
 
-Kzzuho Oku
+Kazuho Oku
 
 Florian Ragwitz (rafl)
 
